@@ -9,7 +9,7 @@ import argparse
 import qisys.script
 
 def print_version(script_name):
-    sys.stdout.write("%s version 3.5.3\n" % script_name)
+    sys.stdout.write("%s version 3.6\n" % script_name)
 
 
 def main():
@@ -28,3 +28,7 @@ def main():
         sys.exit(0)
 
     qisys.script.root_command_main(script_name, parser, modules)
+
+if __name__ == "__main__":
+    sys.argv.pop(0)
+    main()
